;; Generated package description from project.el  -*- no-byte-compile: t -*-
(define-package "project" "0.10.0" "Operations on the current project" '((emacs "26.1") (xref "1.4.0")) :commit "dd2053e8cd3050791bd236d0c1ff5f370170c903" :url "https://elpa.gnu.org/packages/project.html")
